Index: chrome/browser/extensions/activity_log.h |
diff --git a/chrome/browser/extensions/activity_log.h b/chrome/browser/extensions/activity_log.h |
index 4c2379c199c7cc067dfeb5cc2885dc11204020db..eb4f0e5dc1dbb9fcc53bd310ca5b5919251ca92b 100644 |
--- a/chrome/browser/extensions/activity_log.h |
+++ b/chrome/browser/extensions/activity_log.h |
@@ -200,11 +200,11 @@ class ActivityLog : public ProfileKeyedService, |
bool log_activity_to_stdout_; |
bool log_activity_to_ui_; |
// log_arguments controls whether to log API call arguments. By default, we |
// don't log most arguments to avoid saving too much data. In testing mode, |
// argument collection is enabled. We also whitelist some arguments for |
// collection regardless of whether this bool is true. |
- bool log_arguments_; |
+ bool testing_mode_; |
base::hash_set<std::string> arg_whitelist_api_; |
DISALLOW_COPY_AND_ASSIGN(ActivityLog); |
@@ -200,11 +200,11 @@ class ActivityLog : public ProfileKeyedService, |
bool log_activity_to_stdout_; |
bool log_activity_to_ui_; |
- // log_arguments controls whether to log API call arguments. By default, we |
+ // testing_mode_ controls whether to log API call arguments. By default, we |
// don't log most arguments to avoid saving too much data. In testing mode, |
// argument collection is enabled. We also whitelist some arguments for |